<div class="b-data__left">
	<div class="b-slider" ng-controller="nodeCarouselController">
		<div class="b-slider__inner slide js-carousel" id="slider">
			<div class="b-slider__slide item active">
				<div class="b-slider__rhombus" animate-carousel="animateToggle">
					<i class="b-slider__rhombus-shadow"></i>
					<div class="b-slider__rhombus-inner slider">
						<img ng-src="{{ node.status == 'offline' && 'css/b-slider/1.png' || '' }}" class="b-slider__rhombus-image">
					</div>
				</div>
				<i class="b-slider__text">
				<i class="b-slider__label"> quasardb build</i> : {{ nodeBuild || 'No data available yet' }}
				<br>
				<i class="b-slider__label"> quasardb version</i> : {{ nodeVersion || 'No data available yet' }}
				</i>
			</div>
		</div>
		<a class="b-slider__nav b-slider__nav_pos_left" ng-click="showPreviousNode();animateToggle = !animateToggle"></a>
		<a class="b-slider__nav b-slider__nav_pos_right" ng-click="showNextNode();animateToggle = !animateToggle"></a>
	</div>
</div>