<div class="b-data">
	<div class="b-data__inner clearfix">
		<i class="b-data__label"> <i class="b-data__label-icon"></i> <i class="b-data__label-text" > {{ status || "No data available" }} - {{ nodesStatus || "searching..." }}</i> </i>
		<cluster-view></cluster-view>
		<cluster-tab></cluster-tab>
	</div>
	<i class="b-data__shadow"></i>
</div>