<div ng-class="(nodeStats == 'none') ? 'b-charts__info-row js-charts-info-row' : 'b-charts__info-row js-charts-info-row b-charts__info-row_state_expanded'" ng-init="nodeStats = 'none'">
    <div class="b-charts__info-head">
        <a class="b-charts__info-link js-charts-info-link" ng-click="nodeStats = (nodeStats == 'none') ? 'block': 'none'">
            <i class="b-charts__info-link-icon"></i>
            <i class="b-charts__info-link-text">
                Node operation statistics
            </i>
        </a>
    </div>
    <div class="b-charts__info-content js-charts-info-content" ng-style="{'display': nodeStats}">
        <div class="b-charts__statistics">
            <div class="b-charts__statistics-col">
                <div class="b-charts__statistics-label">
                    put
                </div>
                <div class="b-charts__statistics-label">
                    {{ (nodeData[nodeData.length - 1].value.put_failed !== 0) ? (nodeData[nodeData.length - 1].value.put - nodeData[nodeData.length - 1].value.put_failed) : nodeData[nodeData.length - 1].value.put }} <font ng-if="nodeData[nodeData.length - 1].value.put_failed !== 0"> / {{ nodeData[nodeData.length - 1].value.put }}</font>
                </div>
            </div>
            <div class="b-charts__statistics-col">
                <div class="b-charts__statistics-label">
                    get
                </div>
                <div class="b-charts__statistics-label">
                    {{ (nodeData[nodeData.length - 1].value.get_failed !== 0) ? (nodeData[nodeData.length - 1].value.get - nodeData[nodeData.length - 1].value.get_failed) : nodeData[nodeData.length - 1].value.get }} <font ng-if="nodeData[nodeData.length - 1].value.get_failed !== 0"> / {{ nodeData[nodeData.length - 1].value.get }}</font>
                </div>
            </div>
            <div class="b-charts__statistics-col">
                <div class="b-charts__statistics-label">
                    update
                </div>
                <div class="b-charts__statistics-label">
                    {{ (nodeData[nodeData.length - 1].value.update_failed !== 0) ? (nodeData[nodeData.length - 1].value.update - nodeData[nodeData.length - 1].value.update_failed) : nodeData[nodeData.length - 1].value.update }} <font ng-if="nodeData[nodeData.length - 1].value.update_failed !== 0"> / {{ nodeData[nodeData.length - 1].value.update }}</font>
                </div>
            </div>
            <div class="b-charts__statistics-col">
                <div class="b-charts__statistics-label">
                    compare and swap
                </div>
                <div class="b-charts__statistics-label">
                    {{ (nodeData[nodeData.length - 1].value.cas_failed !== 0) ? (nodeData[nodeData.length - 1].value.cas - nodeData[nodeData.length - 1].value.cas_failed) : nodeData[nodeData.length - 1].value.cas }} <font ng-if="nodeData[nodeData.length - 1].value.cas_failed !== 0"> / {{ nodeData[nodeData.length - 1].value.cas }}</font>
                </div>
            </div>
            <div class="b-charts__statistics-col">
                <div class="b-charts__statistics-label">
                    get and update
                </div>
                <div class="b-charts__statistics-label">
                    {{ (nodeData[nodeData.length - 1].value.get_and_update_failed !== 0) ? (nodeData[nodeData.length - 1].value.get_and_update - nodeData[nodeData.length - 1].value.get_and_update_failed) : nodeData[nodeData.length - 1].value.get_and_update }} <font ng-if="nodeData[nodeData.length - 1].value.get_and_update_failed !== 0"> / {{ nodeData[nodeData.length - 1].value.get_and_update }}</font>
                </div>
            </div>
            <div class="b-charts__statistics-col">
                <div class="b-charts__statistics-label">
                    remove
                </div>
                <div class="b-charts__statistics-label">
                    {{ (nodeData[nodeData.length - 1].value.remove_failed !== 0) ? (nodeData[nodeData.length - 1].value.remove - nodeData[nodeData.length - 1].value.remove_failed) : nodeData[nodeData.length - 1].value.remove }} <font ng-if="nodeData[nodeData.length - 1].value.remove_failed !== 0"> / {{ nodeData[nodeData.length - 1].value.remove }}</font>
                </div>
            </div>
            <div class="b-charts__statistics-col">
                <div class="b-charts__statistics-label">
                    remove if
                </div>
                <div class="b-charts__statistics-label">
                    {{ (nodeData[nodeData.length - 1].value.remove_if_failed !== 0) ? (nodeData[nodeData.length - 1].value.remove_if - nodeData[nodeData.length - 1].value.remove_if_failed) : nodeData[nodeData.length - 1].value.remove_if }} <font ng-if="nodeData[nodeData.length - 1].value.remove_if_failed !== 0"> / {{ nodeData[nodeData.length - 1].value.remove_if }}</font>
                </div>
            </div>
            <div class="b-charts__statistics-col">
                <div class="b-charts__statistics-label">
                    get and remove
                </div>
                <div class="b-charts__statistics-label">
                    {{ (nodeData[nodeData.length - 1].value.get_and_remove_failed !== 0) ? (nodeData[nodeData.length - 1].value.get_and_remove - nodeData[nodeData.length - 1].value.get_and_remove_failed) : nodeData[nodeData.length - 1].value.get_and_remove }} <font ng-if="nodeData[nodeData.length - 1].value.get_and_remove_failed !== 0"> / {{ nodeData[nodeData.length - 1].value.get_and_remove }}</font>
                </div>
            </div>
        </div>
    </div>
</div>
