<div ng-class="(sessionStats == 'none') ? 'b-charts__info-row js-charts-info-row' : 'b-charts__info-row js-charts-info-row b-charts__info-row_state_expanded'" ng-init="sessionStats = 'none'">
    <div class="b-charts__info-head">
        <a class="b-charts__info-link js-charts-info-link" ng-click="sessionStats = (sessionStats == 'none') ? 'block': 'none'">
            <i class="b-charts__info-link-icon"></i>
            <i class="b-charts__info-link-text">
                Sessions information by partition
            </i>
        </a>
    </div>
    <div class="b-charts__info-content js-charts-info-content" ng-style="{'display': sessionStats}" ng-controller="nodeSessionsController">
        <div class="b-charts__sessions">
        	<div class="b-charts__sessions-col" ng-repeat="partition in nodePartitions">
        		<div class="b-charts__sessions-chart-inner">
                    <i class="b-charts__sessions-chart" ng-style="{'height': (100 * partition.value) / maxSessions + '%'}"></i>
                </div>
                <div class="b-charts__sessions-label">
                    No. {{ partition.id }}
                </div>
                <div class="b-charts__sessions-value" ng-if="partition.value !== '0'">
                    {{ partition.value }} / {{ maxSessions }}
                </div>
        	</div>
        </div>
    </div>
</div>