.b-tabs {
    position: relative;
    margin: -52px 0 0;
    padding: 0;
    list-style: none;
    z-index: 2;
}

.b-tabs__item {
    float: left;
    cursor: pointer;
}

.b-tabs__link {
    display: block;
    padding: 0 20px 0 8px;
    height: 52px;
    line-height: 52px;
    color: #3b697d;
    text-decoration: none;
}

.b-tabs__link:hover {
    color: #fff;
}

.b-tabs__item_state_current .b-tabs__link {
    background: url(../b-content/bg.jpg);
    color: #fff;
    cursor: default;
}

.b-tabs__item_state_current .b-tabs__link {
    background-position: 142% 0;
}

.b-tabs__item_state_current:first-child .b-tabs__link {
    background-position: 130% 0;
}

.b-tabs__icon,
.b-tabs__text {
    display: inline-block;
    vertical-align: middle;
}

.b-tabs__icon {
    width: 36px;
    height: 36px;
    background: url(icons.png);
}

.b-tabs__link_icon_node .b-tabs__icon {
    background-position: 0 -36px;
}

.b-tabs__item_state_current .b-tabs__link_icon_node .b-tabs__icon {
    background-position: 0 -72px;
}

.b-tabs__text {
    font-style: normal;
}