.b-foot {
    height: 37px;
    line-height: 37px;
    background: #000f15;
}

.b-foot__copy {
    margin: 0;
    color: #015165;
    text-align: center;
    font-size: 12px;
}

.b-foot__highlight {
    font-style: normal;
    color: #00a5ce;
}