.b-head {
    position: relative;
    height: 221px;
    background: #001d29;
    z-index: 1;
}

.b-head__inner {
    height: 100%;
}

.b-head__logo {
    position: relative;
    padding: 12px 0 0;
    text-align: center;
    z-index: 2;
}

.b-head__logo-link {
    display: inline-block;
    vertical-align: top;
}

.b-head__shadow-top {
    position: absolute;
    top: 5px;
    right: 0;
    left: 0;
    height: 132px;
    z-index: 1;
    background: url(top-shadow.png) no-repeat 50% 0;
}

.b-head__shadow-bottom {
    position: absolute;
    bottom: 0;
    right: 0;
    left: 150px;
    height: 53px;
    z-index: 1;
    background: url(bottom-shadow.png) no-repeat;
}