<div class="b-data__right">
	<div class="b-data__section">
		<h2 class="b-data__title"> General data </h2>
		<div>
			<ul class="b-data__list b-data__list_type_small">
				<li class="b-data__list-item">
					<i class="b-data__list-label"> Cluster status </i>
					<i class="b-data__list-value"> <span id="cluster_status">{{ status || "No data available" }}</span> </i>
				</li>
			</ul>
			<ul class="b-data__list b-data__list_type_big">
				<li class="b-data__list-item">
					<i class="b-data__list-label"> Evictions count </i>
					<i class="b-data__list-value"> {{ (clusterData[clusterData.length - 1].value.evictions | bignumber) || 0 }} </i>
				</li>
			</ul>
		</div>
	</div>
	<div class="b-data__section">
		<h2 class="b-data__title"> Aggregated data </h2>
		<div>
			<ul class="b-data__list b-data__list_type_small">
				<li class="b-data__list-item">
					<i class="b-data__list-label"> Persisted size </i>
					<i class="b-data__list-value" ng-if="clusterData[clusterData.length - 1].value.transient_mode !== 'true'"> {{ (clusterData[clusterData.length - 1].value.p_size | bytes) || 0 }}
                        <font ng-if="clusterData[clusterData.length - 1].value.p_max_bytes != null && clusterData[clusterData.length - 1].value.p_max_bytes != 0">/ {{ (clusterData[clusterData.length - 1].value.p_max_bytes | bytes) || 0 }}</font>
                    </i>
                    <i class="b-data__list-value" ng-if="clusterData[clusterData.length - 1].value.transient_mode === 'true'">
                        No persistence
                    </i>
				</li>
				<li class="b-data__list-item">
					<i class="b-data__list-label"> Resident size </i>
					<i class="b-data__list-value"> {{ (clusterData[clusterData.length - 1].value.r_size | bytes) || 0 }}
                        <font ng-if="clusterData[clusterData.length - 1].value.r_max_bytes != null && clusterData[clusterData.length - 1].value.r_max_bytes != 0">/ {{ (clusterData[clusterData.length - 1].value.r_max_bytes | bytes) || 0 }}</font>
                    </i>
				</li>
			</ul>
			<ul class="b-data__list b-data__list_type_big">
				<li class="b-data__list-item">
					<i class="b-data__list-label"> Persisted entries</i>
					<i class="b-data__list-value" ng-if="clusterData[clusterData.length - 1].value.transient_mode !== 'true'"> {{ (clusterData[clusterData.length - 1].value.p_count | bignumber) || 0 }} </i>
					<i class="b-data__list-value" ng-if="clusterData[clusterData.length - 1].value.transient_mode === 'true'"> No persistence </i>
				</li>
				<li class="b-data__list-item">
					<i class="b-data__list-label"> Resident entries</i>
					<i class="b-data__list-value"> {{ (clusterData[clusterData.length - 1].value.r_count | bignumber) || 0 }}
						<font ng-if="clusterData[clusterData.length - 1].value.r_max_count != null && clusterData[clusterData.length - 1].value.r_max_count != 0">/ {{ (clusterData[clusterData.length - 1].value.r_max_count | bignumber) || 0 }}</font>
					</i>
				</li>
			</ul>
		</div>
	</div>
	<div class="b-data__section">
		<h2 class="b-data__title"> Aggregated operations statistics </h2>
		<div>
			<ul class="b-data__list b-data__list_type_small">
				<li class="b-data__list-item">
					<i class="b-data__list-label"> put </i>
					<i class="b-data__list-value"> {{ (clusterData[clusterData.length - 1].value.put | bignumber) || 0 }} <font ng-if="clusterData[clusterData.length - 1].value.put_failed !== 0">/ {{ (clusterData[clusterData.length - 1].value.put_failed + clusterData[clusterData.length - 1].value.put | bignumber) || 0 }}</font></i>
				</li>
				<li class="b-data__list-item">
					<i class="b-data__list-label"> get </i>
					<i class="b-data__list-value"> {{ (clusterData[clusterData.length - 1].value.get | bignumber) || 0 }} <font ng-if="clusterData[clusterData.length - 1].value.get_failed !== 0">/ {{ (clusterData[clusterData.length - 1].value.get_failed + clusterData[clusterData.length - 1].value.get | bignumber) || 0 }}</font></i>
				</li>
				<li class="b-data__list-item">
					<i class="b-data__list-label"> update </i>
					<i class="b-data__list-value"> {{ (clusterData[clusterData.length - 1].value.update | bignumber) || 0 }} <font ng-if="clusterData[clusterData.length - 1].value.update_failed !== 0">/ {{ (clusterData[clusterData.length - 1].value.update_failed + clusterData[clusterData.length - 1].value.update | bignumber) || 0 }}</font></i>
				</li>
				<li class="b-data__list-item">
					<i class="b-data__list-label"> compare and swap </i>
					<i class="b-data__list-value"> {{ (clusterData[clusterData.length - 1].value.cas | bignumber) || 0 }} <font ng-if="clusterData[clusterData.length - 1].value.cas_failed !== 0">/ {{ (clusterData[clusterData.length - 1].value.cas_failed + clusterData[clusterData.length - 1].value.cas | bignumber) || 0 }}</font></i>
				</li>
			</ul>
			<ul class="b-data__list b-data__list_type_big">
				<li class="b-data__list-item">
					<i class="b-data__list-label"> get and update </i>
					<i class="b-data__list-value"> {{ (clusterData[clusterData.length - 1].value.get_and_update | bignumber) || 0 }} <font ng-if="clusterData[clusterData.length - 1].value.get_and_update_failed !== 0">/ {{ (clusterData[clusterData.length - 1].value.get_and_update_failed + clusterData[clusterData.length - 1].value.get_and_update | bignumber) || 0 }}</font></i>
				</li>
				<li class="b-data__list-item">
					<i class="b-data__list-label"> remove </i>
					<i class="b-data__list-value"> {{ (clusterData[clusterData.length - 1].value.remove | bignumber) || 0 }} <font ng-if="clusterData[clusterData.length - 1].value.remove_failed !== 0">/ {{ (clusterData[clusterData.length - 1].value.remove_failed + clusterData[clusterData.length - 1].value.remove | bignumber) || 0 }}</font></i>
				</li>
				<li class="b-data__list-item">
					<i class="b-data__list-label"> remove if </i>
					<i class="b-data__list-value"> {{ (clusterData[clusterData.length - 1].value.remove_if | bignumber) || 0 }} <font ng-if="clusterData[clusterData.length - 1].value.remove_if_failed !== 0">/ {{ (clusterData[clusterData.length - 1].value.remove_if_failed + clusterData[clusterData.length - 1].value.remove_if | bignumber) || 0 }}</font></i>
				</li>
				<li class="b-data__list-item">
					<i class="b-data__list-label"> get and remove </i>
					<i class="b-data__list-value"> {{ (clusterData[clusterData.length - 1].value.get_and_remove | bignumber) || 0 }} <font ng-if="clusterData[clusterData.length - 1].value.get_and_remove_failed !== 0">/ {{ (clusterData[clusterData.length - 1].value.get_and_remove_failed + clusterData[clusterData.length - 1].value.get_and_remove | bignumber) || 0 }}</font></i>
				</li>
			</ul>
		</div>
	</div>
</div>
