<div class="b-data">
    <div class="b-data__inner clearfix">
        <i class="b-data__label">
            <i class="b-data__label-icon"></i>
            <i class="b-data__label-text">
                {{ status }}
            </i>
        </i>
        <node-carousel></node-carousel>
		<node-tab></node-tab>
	</div>
	<i class="b-data__shadow"></i>
</div>

<div class="b-charts__info">
	<node-operations></node-operations>
	<br/>
	<node-sessions></node-sessions>
</div>

<div class="b-charts__actions clearfix" ng-controller="nodeDownloadController">
    <a id="node_data" class="b-charts__actions-link" ng-click="getRawNodeData();">
        <i class="b-charts__actions-icon"></i>
        <i class="b-charts__actions-text">
            Raw JSON data
        </i>
    </a>
    <a id="node_conf" class="b-charts__actions-link" ng-click="getRawNodeConf();">
        <i class="b-charts__actions-icon"></i>
        <i class="b-charts__actions-text">
            Configuration as JSON
        </i>
    </a>
</div>