.b-rhombus {
    width: 363px;
    height: 355px;
    background: url(bg.png);
}

.b-rhombus__inner {
    position: relative;
    top: 56px;
    left: 56px;
    width: 244px;
    height: 244px;
}

.b-rhombus__item-inner {
    width: 48px;
    height: 122px;
    position: absolute;
    top: 0;
    left: 50%;
    margin-left: -20px;
    -ms-transform-origin: bottom center;
    -moz-transform-origin: bottom center;
    -webkit-transform-origin: bottom center;
    transform-origin: bottom center;
    z-index: 1;
}

.b-rhombus__item-inner_state_hover {
    z-index: 2;
}

.b-rhombus__item {
    width: 48px;
    height: 58px;
    line-height: 66px;
    position: absolute;
    top: -30px;
    left: 0;
    background: url(rhombus.png);
    text-align: center;
}

.b-rhombus__inner_size_16 .b-rhombus__item {
    top: -24px;
    -webkit-transform: scale(0.8, 0.8);
}

.b-rhombus__inner_size_20 .b-rhombus__item {
    top: -27px;
    -webkit-transform: scale(0.6, 0.6);
}

.b-rhombus__inner_size_many .b-rhombus__item {
    top: -24px;
    -webkit-transform: scale(0.45, 0.45);
}

.b-rhombus__icon {
    display: inline-block;
    width: 23px;
    height: 23px;
    background: url(icons.png);
}

.b-rhombus__icon_icon_warning {
    background-position: 0 -23px;
}

.b-rhombus__icon_icon_close {
    background-position: 0 -46px;
}

.b-rhombus__icon_icon_data {
    background: none;
}

.b-rhombus__dropdown-wrap {
    position: absolute;
    margin: 25px 0 0 -132px;
    width: 265px;
    z-index: 10;
    line-height: normal;
    text-align: left;
    font-size: 12px;
    transition: 0.2s top, 0.2s left;
}

.b-rhombus__item-inner_state_hover .b-rhombus__dropdown-wrap {
    display: block;
}

.b-rhombus__dropdown-wrap_size_16 .b-rhombus__dropdown-wrap {
    margin: 16px 0 0 -136px;
}

.b-rhombus__dropdown-wrap_size_20 .b-rhombus__dropdown-wrap {
    margin: 10px 0 0 -138px;
}

.b-rhombus__dropdown-wrap_size_many .b-rhombus__dropdown-wrap {
    margin: 5px 0 0 -138px;
}

.b-rhombus__dropdown {
    position: relative;
    background: #003f52;
    border-radius: 5px;
    overflow: hidden;
    z-index: 2;
}

.b-rhombus__dropdown-inner {
    padding: 15px;
}

.b-rhombus__dropdown-content {
    margin: 5px 0 0;
    padding: 10px 0;
    border-top: 1px solid #067799;
    border-bottom: 1px solid #067799;
}

.b-rhombus__dropdown-text {
    padding: 10px 0 0 10px;
}

.b-rhombus__dropdown-corner-inner {
    position: absolute;
    top: -14px;
    right: 0;
    left: 0;
    height: 15px;
}

.b-rhombus__dropdown-corner {
    position: absolute;
    bottom: 0;
    left: 50%;
    margin: 0 0 0 -7px;
    width: 0;
    height: 0;
    border-style: solid;
    border-width: 0 7px 8px 7px;
    border-color: transparent transparent #003f52 transparent;
}

.b-rhombus__dropdown-shadow {
    position: absolute;
    top: 6px;
    right: -4px;
    bottom: -4px;
    left: 6px;
    background: #000;
    border-radius: 5px;
    opacity: .5;
}

.b-rhombus__dropdown-more-inner {
    margin: 13px 0 0;
    text-align: right;
}

.b-rhombus__dropdown-more-link {
    text-decoration: none;
    color: #fff;
}

.b-rhombus__dropdown-more-link:hover {
    color: #0ff;
}

.b-rhombus__dropdown-more-text,
.b-rhombus__dropdown-more-icon {
    display: inline-block;
    vertical-align: middle;
    cursor:pointer;
}

.b-rhombus__dropdown-more-text {
    font-style: normal;
}

.b-rhombus__dropdown-more-icon {
    margin: 0 0 0 6px;
    width: 22px;
    height: 25px;
    background: url(../img/more-rhombus.png);
}