<div class="b-charts b-charts_type_normal clearfix">
	<div class="b-charts__item" ng-repeat="chart in charts">
		<h2 class="b-charts__title">
			<i class="{{ chart.icon }}"></i>
			<i class="b-charts__title-text"> 
				{{ chart.label }} 
			</i>
		</h2>
		<div class="b-charts__chart-inner">
			<i ng-if="chart.show_limiter === 'true'" class="b-charts__saturation">
                Saturation
            </i>
			<chart
				name="{{ chart.name }}"
			 	formatNumber="{{ chart.formatNumber }}"
			  	data="chart.data"
			  	max="{{ chart.max }}"
	    		renderer="{{ chart.renderer }}"
	    		dotted="{{ chart.dotted }}"
	    		width="{{ chart.width }}"
	    		height="{{ chart.height }}"
	    		stroke="{{ chart.stroke }}"
				preserve="{{ chart.preserve }}"
				color="{{ chart.color }}"
				showLimiter="{{ chart.show_limiter }}">
			</chart>
    	</div>
	</div>
</div>