<div id="shortcuts">
	<ul class="tabrow">
    	<li ng-repeat="range in ranges" class="{{ range.selected }}" ng-click="launch($index, range.action)">
            <a>{{ range.label }}</a>
        </li>
	</ul>
</div>
<div class="b-charts__chart-inner">
	<div id="y_axis_1"></div>
	<div id="graph"></div>
	<div id="y_axis_2"></div>
	<div id="timeline"></div>
	<div id="preview"></div>
</div>