.b-slider {
    position: relative;
    width: 363px;
    height: 355px;
    background: url(bg.png);
}

.b-slider__inner {
    position: relative;
    height: 100%;
    z-index: 1;
    overflow: hidden;
}

.b-slider__nav {
    position: absolute;
    top: 50%;
    margin: -87px 0 0;
    width: 55px;
    height: 174px;
    background: url(nav.png);
    cursor: pointer;
    z-index: 2;
}

.b-slider__nav_pos_left {
    left: -5px;
}

.b-slider__nav_pos_left:hover {
    background-position: 0 -348px;
}

.b-slider__nav_pos_right {
    right: -5px;
    background-position: 0 -174px;
}

.b-slider__nav_pos_right:hover {
    background-position: 0 -522px;
}

.b-slider__text {
    position: absolute;
    bottom: 10px;
    left: 10px;
    font-style: normal;
    font-size: 13px;
}

.b-slider__label {
    color: #00c3e3;
    font-style: normal;
}

.b-slider__slide {
    position: relative;
    display: none;
    height: 100%;
    transition: .6s ease-in-out left;
}

.b-slider__rhombus {
    position: absolute;
    top: 50%;
    left: 50%;
    margin: -123px 0 0 -107px;
    width: 214px;
    height: 246px;
    background: url(rhombus.png);
    text-align: center;
}

.b-slider__rhombus-shadow {
    position: absolute;
    top: 15px;
    right: 13px;
    width: 141px;
    height: 134px;
    background: url(shadow.png);
}

.b-slider__rhombus-inner {
    display: table-cell;
    width: 214px;
    height: 246px;
    vertical-align: middle;
}

.item.active,
.next,
.prev {
    display: block;
}

.active {
    left: 0;
}

.next,
.prev {
    position: absolute;
    top: 0;
    width: 100%;
}

.next {
    left: 100%;
}

.prev {
    left: -100%;
}

.next.left,
.prev.right {
    left: 0;
}

.active.left {
    left: -100%;
}

.active.right {
    left: 100%;
}