.b-data {
    padding: 60px 0 0;
}

.b-data__label {
    position: absolute;
    top: 33px;
    left: 10px;
}

.b-data__label_type_inline {
    position: static;
}

.b-data__label-icon,
.b-data__label-text {
    display: inline-block;
    vertical-align: middle;
}

.b-data__label-icon {
    width: 8px;
    height: 11px;
    background: #00ffff;
    box-shadow: 0 0 8px rgba(0, 255, 255, .8);
}

.b-data__label-text {
    font-style: normal;
    font-size: 13px;
}

.b-data__left {
    float: left;
    width: 365px;
}

.b-data__right {
    width: 585px;
    padding: 0px 0 0;
    float: right;
}

.b-data__section {
    margin: 48px 0 0;
}

.b-data__section:first-child {
    margin: 0;
}

.b-data__title {
    margin: 0 0 1px;
    font-size: 16px;
}

.b-data__list {
    display: inline-block;
    vertical-align: top;
    margin: 0;
    padding: 0;
    list-style: none;
    color: #c7e6f6;
    font-size: 13px;
}

.b-data__list_style_white {
    color: #fff;
}

.b-data__list_type_small {
    width: 270px;
    margin-right: 0;
}

.b-data__list_type_big {
    width: 295px;
}

.b-data__list-label,
.b-data__list-value {
    display: inline-block;
    vertical-align: middle;
    font-style: normal;
}

.b-data__list-failed_value {
    color: #B22222;
    font-weight:bold;
}

.b-data__list-label {
    padding: 0 5px 0 0;
}

.b-data__list_type_small .b-data__list-label {
    width: 110px;
}

.b-data__list_type_small .b-data__list-value {
    width: 150px;
}

.b-data__list_type_big .b-data__list-label {
    width: 110px;
}

.b-data__list_type_big .b-data__list-value {
    width: 140px;
}

.b-data__list_type_normal .b-data__list-label  {
    width: 110px;
}

.b-data__list_type_normal .b-data__list-value {
    width: auto;
}

.b-data__shadow {
    margin: 12px 0 0;
    display: block;
    background: url(shadow.png) no-repeat 50% 0;
    height: 184px;
}
