<div class="b-container" ng-app="cluster" ng-init="tab=1; myVar1='b-tabs__item_state_current'">
    <header class="b-head">
        <div class="b-head__inner b-page__container">
            <div class="b-head__logo">
                <a class="b-head__logo-link">
                    <img src="css/b-head/logo.png" alt="QuasarDB">
                </a>
            </div>
            <i class="b-head__shadow-top"></i>
            <i class="b-head__shadow-bottom"></i>
        </div>
    </header>
    <div class="b-main">
        <div class="b-page__container">
            <ul class="b-tabs clearfix">
                <li class="b-tabs__item" ng-class="myVar1">
                    <a class="b-tabs__link b-tabs__link_icon_cluster" ng-click="tab = 1; myVar1='b-tabs__item_state_current'; myVar2=''">
                        <i class="b-tabs__icon"></i>
                        <i class="b-tabs__text">
                            Your cluster
                        </i>
                    </a>
                </li>
                <li class="b-tabs__item" ng-class="myVar2">
                    <a class="b-tabs__link b-tabs__link_icon_node" ng-click="tab = 2; myVar2='b-tabs__item_state_current'; myVar1=''">
                        <i class="b-tabs__icon"></i>
                        <i class="b-tabs__text">
                            Node data
                        </i>
                    </a>
                </li>
            </ul>
        </div>

        <div class="b-content">
        	<div ng-show="tab == 1">
	        	<div class="b-page__container">
					<cluster-data></cluster-data>
					<cluster-charts></cluster-charts>
				</div>
			</div>
			<div ng-show="tab == 2" ng-controller="nodesController">
				<div class="b-page__container">
					<node-data node-id="{{ node.id }}"></node-data>
					<node-charts node-id="{{ node.id }}"></node-charts>
				</div>
	        </div>
			<div class="b-content__shadow"></div>
        </div>
    </div>
    <footer class="b-foot">
        <div class="b-page__container">
            <p class="b-foot__copy">
                &copy; Copyright 2009-2017,
                <i class="b-foot__highlight">quasardb</i> SAS. All rights reserved.
            </p>
        </div>
    </footer>
</div>

<div class="js-dropdown-inner"></div>
