.b-page {
    background: #134355;
    font-family: Arial, Helvetica, sans-serif;
    color: #fff;
    font-size: 14px;
}

.b-page__container {
    position: relative;
    left: 15px;
    width: 960px;
    margin: auto;
}