/*************************/
/* Override rickshaw CSS */
/*************************/

.rickshaw_graph .y_grid .tick,
.rickshaw_graph .x_grid_d3 .tick {
	z-index: -1;
	stroke: rgba(255, 255, 255, 0.20);
	stroke-width: 1px;
	stroke-dasharray: 1 1;
}
.rickshaw_graph .x_tick.glow .title,
.rickshaw_graph .y_ticks.glow text {
	fill: white;
	color: white;
	text-shadow: 
		-1px 1px 0 rgba(255, 255, 255, 0.1),
		1px -1px 0 rgba(255, 255, 255, 0.1),
		1px 1px 0 rgba(255, 255, 255, 0.1),
		0px 1px 0 rgba(255, 255, 255, 0.1),
		0px -1px 0 rgba(255, 255, 255, 0.1),
		1px 0px 0 rgba(255, 255, 255, 0.1),
		-1px 0px 0 rgba(255, 255, 255, 0.1),
		-1px -1px 0 rgba(255, 255, 255, 0.1);
}

.rickshaw_annotation_timeline {
    border-top: 1px solid #E0E0E0;
    height: 5px;
    margin-top: 5px;
    margin-right: 75px;
    position: relative;
}

.rickshaw_annotation_timeline .annotation .content {
	background: white;
	color: black;
	opacity: 0.9;
	padding: 5px 5px;
	box-shadow: 0 0 2px rgba(2, 0, 0, 0.8);
	border-radius: 3px;
	position: relative;
	z-index: 20;
	font-size: 12px;
	padding: 6px 8px 8px;
	top: 20px;
	left: -11px;
	width: 160px;
	display: none;
	cursor: pointer;
}

/* Chart popups */
.rickshaw_graph .detail .x_label { 
	display: none 
}

.rickshaw_graph .detail .item { 
	line-height: 1.4; 
	padding: 0.5em 
}

.detail_swatch { 
	float: right; 
	display: inline-block; 
	width: 10px; 
	height: 10px; 
	margin: 0 4px 0 0 
}

.rickshaw_graph .detail .date {
	color: #a0a0a0 
}

.rickshaw_graph .detail .item.right {
}

/* Y axis */
#y_axis_1 {
	position: absolute;
	top: 0;
	bottom: 0;
	left : 0;
	width: 60px;
}

#y_axis_2 {
	position: absolute;
	top: 0;
	bottom: 0;
	left : 360px;
	width: 40px;
}

/* Preview slider */
.rickshaw_range_slider_preview .frame {
	stroke-width: 1px;
	fill: #134355;
	fill-opacity: 0.1;
}

/*************************/
/* Charts CSS */
/*************************/

/* */
#history {
	height: 25px;
	-moz-border-radius-bottomright: 50px;
	border-bottom-right-radius: 50px;
}
.tabrow {
    text-align: left;
    list-style: none;
    margin: 0px 1px;
    padding: 0px 0px 0px 10px;
    line-height: 24px;
    height: 24px;
    overflow: hidden;
    font-size: 12px;
    font-family: verdana;
    position: relative;
}
.tabrow li {
    border: 1px solid #AAA;
    display: inline-block;
    position: relative;
    z-index: 0;
    border-top-left-radius: 4px;
    border-top-right-radius: 4px;
    box-shadow: 0 3px 3px rgba(0, 0, 0, 0.4), inset 0 0px 0 #FFF;
    text-shadow: 0 1px #FFF;
    margin: 0px 0px 0px -1px;
    padding: 0 15px;
    cursor: pointer;
}
.tabrow a {
	color: #555;
	text-decoration: none;
}
.tabrow li.selected {
    background: #FFF;
    color: #333;
    z-index: 2;
    border-bottom-color: #FFF;
    cursor: default;
}
.tabrow:before {
    position: absolute;
    content: " ";
    width: 85%;
    bottom: 0;
    left: 0;
    border-bottom: 1px solid #AAA;
    z-index: 1;
}
.tabrow li:before,
.tabrow li:after {
    border: 1px solid #AAA;
    position: absolute;
    bottom: -1px;
    width: 5px;
    height: 5px;
    content: " ";
}
.tabrow li:before {
    left: -6px;
    border-bottom-right-radius: 6px;
    border-width: 0 1px 1px 0;
    box-shadow: 2px 2px 0 #D1D1D1;
}
.tabrow li:after {
    right: -6px;
    border-bottom-left-radius: 6px;
    border-width: 0 0 1px 1px;
    box-shadow: -2px 2px 0 #D1D1D1;
}
.tabrow li.selected:before {
    box-shadow: 2px 2px 0 #FFF;
}
.tabrow li.selected:after {
    box-shadow: -2px 2px 0 #FFF;
}


.b-charts {
    margin: -115px -10px 0 -18px;
}

.b-charts_type_normal {
    margin-top: 0;
}

.b-charts__item {
    display: inline-block;
    width: 475px;
    margin: 25px 0 0;
    vertical-align: top;
}

.b-charts__title {
    margin: 0 0 8px;
    padding: 0 0 0 26px;
    font-size: 14px;
    font-weight: normal;
}

.b-charts__title-icon,
.b-charts__title-text {
    display: inline-block;
    vertical-align: middle;
}

.b-charts__title-icon {
    margin: 0 5px 0 0;
    width: 32px;
    height: 32px;
    background: url(icons.png);
}

.b-charts__title-icon_icon_cpu {
    background-position: 0 0;
}

.b-charts__title-icon_icon_memory {
    background-position: 0 -32px;
}

.b-charts__title-icon_icon_resident {
    background-position: 0 -64px;
}

.b-charts__title-icon_icon_traffic {
    background-position: 0 -96px;
}

.b-charts__title-text {
    font-style: normal;
}

.b-charts__title-text-dark {
    font-style: normal;
    color: #467287;
}

.b-charts__chart-inner {
    position: relative;
}

.b-charts__saturation {
    position: absolute;
    right: 75px;
    bottom: 95%;
    margin: 0 2 -2px;
    padding: 25px 0 0;
    font-style: normal;
    background: url(warning.png) no-repeat 50% 0;
}

.b-charts__info {
    margin: -150px 0 0;
}

.b-charts__info-row {
    margin: 35px 0 0;
}

.b-charts__info-row:first-child {
    margin: 0;
}

.b-charts__info-head {
    padding: 0 0 0 7px;
}

.b-charts__info-link {
    color: #fff;
    text-decoration: none;
    cursor: pointer;
}

.b-charts__info-link:hover {
    color: #C7E6F6;
}

.b-charts__info-link-icon,
.b-charts__info-link-text {
    display: inline-block;
    vertical-align: middle;
}

.b-charts__info-link-icon {
    margin: 0 9px 0 0;
    width: 0;
    height: 0;
    border-style: solid;
    border-width: 7px 0 7px 10px;
    border-color: transparent transparent transparent #006577;
}

.b-charts__info-row_state_expanded .b-charts__info-link-icon {
    margin-right: 5px;
    border-width: 10px 7px 0 7px;
    border-color: #006577 transparent transparent transparent;
}

.b-charts__info-link-text {
    font-style: normal;
    font-size: 16px;
    font-weight: bold;
}

.b-charts__info-content {
    margin: 12px 0 0;
    display: none;
}

.b-charts__statistics,
.b-charts__sessions {
    display: table;
    width: 100%;
    padding: 0 0 13px;
    border-bottom: 1px solid #16303c;
    text-align: center;
    color: #c7e6f6;
    font-size: 13px;
}

.b-charts__sessions {
    font-size: 11px;
}

.b-charts__statistics-col,
.b-charts__sessions-col {
    position: relative;
    display: table-cell;
    vertical-align: top;
}

.b-charts__statistics-col:before,
.b-charts__sessions-col:before {
    position: absolute;
    top: 0;
    left: 0;
    width: 1px;
    height: 41px;
    background: #16303c;
    content: '';
}

.b-charts__sessions-col:before {
    height: 53px;
}

.b-charts__statistics-col:first-child:before,
.b-charts__sessions-col:first-child:before {
    display: none;
}

.b-charts__statistics-label {
    margin: -6px 0 8px;
}

.b-charts__sessions-chart-inner {
    position: relative;
    height: 50px;
}

.b-charts__sessions-chart {
    position: absolute;
    bottom: 0;
    left: 50%;
    margin: 0 0 0 -7px;
    width: 15px;
    background: #059ab3;
}

.b-charts__sessions-label {
    margin: 10px 0 0;
    color: #fff;
}

.b-charts__sessions-value {
    color: #9d9d9d;
}

.b-charts__actions {
    margin: 50px 0;
    padding: 0 0 10px 3px;
    border-bottom: 1px solid #16303c;
}

.b-charts__actions-link {
    margin: 0 0 0 50px;
    float: left;
    text-decoration: none;
    color: #fff;
    transition: 0.2s color;
}

.b-charts__actions-link:hover {
    color: #00C3E3;
    cursor: pointer;
}

.b-charts__actions-link:first-child {
    margin: 0;
}

.b-charts__actions-icon,
.b-charts__actions-text {
    display: inline-block;
    vertical-align: bottom;
}

.b-charts__actions-icon {
    margin: 0 8px 0 0;
    width: 32px;
    height: 32px;
    background: url(download.png);
}

.b-charts__actions-link:hover .b-charts__actions-icon {
    opacity: .8;
    filter: alpha(opacity=80);
}

.b-charts__actions-text {
    font-style: normal;
    font-size: 13px;
}