<div class="b-data__right">
    {{
        node = nodeData[nodeData.length - 1];
        ""
    }}
    <div class="b-data__section">
        <h2 class="b-data__title">
            Node
        </h2>
        <div>
            <ul class="b-data__list b-data__list_type_normal">
                <li class="b-data__list-item">
                    <i class="b-data__list-label">
                        ID
                    </i>
                    <i class="b-data__list-value">
                        {{ node.value.node_id || "N/A" }}
                    </i>
                </li>
                <li class="b-data__list-item">
                    <i class="b-data__list-label">
                        Machine
                    </i>
                    <i class="b-data__list-value">
                        {{
                            hostname = node.value.node_hostname || "N/A";
                            ""
                        }}
                        <font ng-if="node.value.node_hostname != 'unknown'">{{hostname}}</font>
                    </i>
                </li>
                <li class="b-data__list-item">
                    <i class="b-data__list-label">
                        IP endpoint
                    </i>
                    <i class="b-data__list-value">
                        {{
                            ip = node.value.node_ip || "N/A";
                            ""
                        }}
                        {{ip}}
                    </i>
                </li>
            </ul>
        </div>
    </div>
    <div class="b-data__section">
        <h2 class="b-data__title">
            Machine configuration
        </h2>
        <div>
            <ul class="b-data__list b-data__list_type_normal">
                <li class="b-data__list-item">
                    <i class="b-data__list-label">
                        OS
                    </i>
                    <i class="b-data__list-value">
                        {{ node.value.os || "N/A" }}
                    </i>
                </li>
                <li class="b-data__list-item">
                    <i class="b-data__list-label">
                        CPU usage
                    </i>
                    <i class="b-data__list-value">
                        <font ng-if="node.value.cpu_average === undefined">
                            N/A
                        </font>
                        <font ng-if="node.value.cpu_average !== undefined">
                            {{ (node.value.cpu_average | number) }} %
                        </font>
                    </i>
                </li>
                <li class="b-data__list-item">
                    <i class="b-data__list-label">
                        CPU(s)
                    </i>
                    <i class="b-data__list-value">
                        {{ (node.value.nbCpu | number) || "N/A" }}
                    </i>
                </li>
            </ul>
        </div>
    </div>
    <div class="b-data__section">
        <h2 class="b-data__title">
            Node data
        </h2>
        <div>
            <ul class="b-data__list b-data__list_type_small">
                <li class="b-data__list-item">
                    <i class="b-data__list-label">
                        Uptime
                    </i>
                    <i class="b-data__list-value">
                        {{ node.value.uptime || 0 }}
                    </i>
                </li>
                <li class="b-data__list-item">
                    <i class="b-data__list-label">
                        Virtual memory
                    </i>
                    <i class="b-data__list-value">
                        {{ (node.value.vm | bytes) || 0 }}
                    </i>
                </li>
                <li class="b-data__list-item">
                    <i class="b-data__list-label">
                        Physical memory
                    </i>
                    <i class="b-data__list-value">
                        {{ (node.value.ram | bytes) || 0 }}
                    </i>
                </li>
                <li class="b-data__list-item">
                    <i class="b-data__list-label">
                        Disk capacity
                    </i>
                    <i class="b-data__list-value" ng-if="(node.value.free !== 0) && (node.value.disk !== 0)">
                        {{ (node.value.free | bytes) || 0 }} / {{ (node.value.disk | bytes) || 0 }}
                    </i>
                    <i class="b-data__list-value" ng-if="(node.value.free === 0) && (node.value.disk === 0) && (node.value.transient_mode === 'false')">
                        No data available yet
                    </i>
                    <i class="b-data__list-value" ng-if="node.value.transient_mode === 'true'">
                        No persistence
                    </i>
                </li>
            </ul>
            <ul class="b-data__list b-data__list_type_big b-data__list_type_normal">
                <li class="b-data__list-item">
                    <i class="b-data__list-label">
                        Evictions count
                    </i>
                    <i class="b-data__list-value">
                        {{ (node.value.evictions | bignumber) || 0 }}
                    </i>
                </li>
                <li class="b-data__list-item">
                    <i class="b-data__list-label">
                        Resident entries
                    </i>
                    <i class="b-data__list-value">
                        {{ (node.value.r_count | bignumber) || 0 }}
                        <font ng-if="node.value.r_max_count != null && node.value.r_max_count != 0">/ {{ (node.value.r_max_count | bignumber) || 0 }}</font>
                    </i>
                </li>
                <li class="b-data__list-item">
                    <i class="b-data__list-label">
                        Resident size
                    </i>
                    <i class="b-data__list-value">
                        {{ (node.value.r_size | bytes) || 0 }}
                        <font ng-if="node.value.r_max_bytes != null && node.value.r_max_bytes != 0">/ {{ (node.value.r_max_bytes | bytes) || 0 }}</font>
                    </i>
                </li>
                <li class="b-data__list-item">
                    <i class="b-data__list-label">
                        Persisted entries
                    </i>
                    <i class="b-data__list-value" ng-if="node.value.transient_mode !== 'true'">
                        {{ (node.value.p_count | bignumber) || 0 }}
                    </i>
                    <i class="b-data__list-value" ng-if="node.value.transient_mode === 'true'">
                        No persistence
                    </i>
                </li>
                <li class="b-data__list-item">
                    <i class="b-data__list-label">
                        Persisted size
                    </i>
                    <i class="b-data__list-value" ng-if="node.value.transient_mode !== 'true'">
                        {{ (node.value.p_size | bytes) || 0 }} <font ng-if="node.value.p_max_bytes != null && node.value.p_max_bytes != 0">/ {{ (node.value.p_max_bytes | bytes) || 0 }}</font>
                    </i>
                    <i class="b-data__list-value" ng-if="node.value.transient_mode === 'true'">
                        No persistence
                    </i>
                </li>
            </ul>
        </div>
    </div>
</div>
